@@ -7,16 +7,16 @@
 #' `plot.ped` is in essence an elaborate wrapper for
 #' [kinship2::plot.pedigree()].
 #'
-#' @param x a [ped()] object.
-#' @param marker either a vector of names or indices referring to markers
+#' @param x A [ped()] object.
+#' @param marker Either a vector of names or indices referring to markers
 #'   attached to `x`, a `marker` object, or a list of such. The genotypes for
 #'   the chosen markers are written below each individual in the pedigree, in
-#'   the format determined by `sep` and `missing`. See also `showEmpty`
-#'   below. If NULL (the default), no genotypes are plotted.
-#' @param sep a character of length 1 separating alleles for diploid markers.
-#' @param missing the symbol (integer or character) for missing alleles.
-#' @param showEmpty a logical, indicating if empty genotypes should be included.
-#' @param labs a vector or function controlling the individual labels included
+#'   the format determined by `sep` and `missing`. See also `showEmpty`. If NULL
+#'   (the default), no genotypes are plotted.
+#' @param sep A character of length 1 separating alleles for diploid markers.
+#' @param missing The symbol (integer or character) for missing alleles.
+#' @param showEmpty A logical, indicating if empty genotypes should be included.
+#' @param labs A vector or function controlling the individual labels included
 #'   in the plot. Alternative forms:
 #'
 #'   * If `labs` is a vector with nonempty intersection with `labels(x)`, these
@@ -32,37 +32,42 @@
 #'   * If `labs` is a function, it will be replaced with `labs(x)` and handled
 #'   as above. (See Examples.)
 #'
-#' @param title the plot title. If NULL or '', no title is added to the plot.
-#' @param col a vector of colours for the pedigree members, recycled if
+#' @param title The plot title. If NULL (default) or '', no title is added to
+#'   the plot.
+#' @param col A vector of colours for the pedigree members, recycled if
 #'   necessary. Alternatively, `col` can be a list assigning colours to specific
 #'   members. For example if `col = list(red = "a", blue = c("b", "c"))` then
 #'   individual "a" will be red, "b" and "c" blue, and everyone else black. By
-#'   default everyone is drawn black.
-#' @param aff a vector of ID labels indicating pedigree members whose plot
-#'   symbols should be filled.
-#' @param hatched a vector of ID labels indicating pedigree members whose plot
-#'   symbols should be hatched.
+#'   default everyone is black.
+#' @param aff A vector of labels identifying members whose plot symbols should
+#'   be filled. (This is typically used in medical pedigrees to indicate
+#'   affected members.)
+#' @param carrier A vector of labels identifying members whose plot symbols
+#'   should be marked with a dot. (This is typically used in medical pedigrees
+#'   to indicate unaffected carriers of the disease allele.)
+#' @param hatched A vector of labels identifying members whose plot symbols
+#'   should be hatched.
 #' @param shaded (Deprecated) synonym of `hatched`
-#' @param deceased a vector of ID labels indicating deceased pedigree members.
-#' @param starred a vector of ID labels indicating pedigree members that should
-#'   be marked with a star in the pedigree plot.
-#' @param hints a list with alignment hints passed on to
-#'   `kinship2::align.pedigree()`. Usually not necessary.
-#' @param fouInb either "autosomal" (default), "x" or NULL. If "autosomal" or
+#' @param deceased A vector of labels indicating deceased pedigree members.
+#' @param starred A vector of labels indicating pedigree members that should be
+#'   marked with a star in the pedigree plot.
+#' @param hints A list with alignment hints passed on to
+#'   `kinship2::align.pedigree()`. Rarely necessary, but see Examples.
+#' @param fouInb Either "autosomal" (default), "x" or NULL. If "autosomal" or
 #'   "x", inbreeding coefficients are added to the plot above the inbred
 #'   founders. If NULL, or if no founders are inbred, nothing is added.
-#' @param margins a numeric of length 4 indicating the plot margins. For
+#' @param textInside,textAbove Character vectors of text to be printed inside or
+#'   above pedigree symbols.
+#' @param margins A numeric of length 4 indicating the plot margins. For
 #'   singletons only the first element (the 'bottom' margin) is used.
 #' @param keep.par A logical (default = FALSE). If TRUE, the graphical
 #'   parameters are not reset after plotting, which may be useful for adding
 #'   additional annotation.
 #' @param yadj A tiny adjustment sometimes needed to fix the appearance of
 #'   singletons.
-#' @param skipEmptyGenotypes Deprecated; use `showEmpty` instead.
-#' @param skip.empty.genotypes Deprecated; use `showEmpty` instead.
-#' @param id.labels Deprecated; use `labs` instead
-#' @param \dots arguments passed on to `plot.pedigree` in the `kinship2`
+#' @param \dots Arguments passed on to `plot.pedigree` in the `kinship2`
 #'   package. In particular `symbolsize` and `cex` can be useful.
+#'
 #' @author Magnus Dehli Vigeland
 #' @seealso [kinship2::plot.pedigree()]
 #'
@@ -118,31 +123,14 @@
 #' hints = list(order = 1:7, spouse = rbind(c(3,5,0), c(5,4,0)))
 #' plot(y, hints = hints) # good
 #'
-#' @importFrom graphics text
+#' @importFrom graphics points text
 #' @export
 plot.ped = function(x, marker = NULL, sep = "/", missing = "-", showEmpty = FALSE,
-                    labs = labels(x), title = NULL, col = 1, aff = NULL, hatched = NULL,
-                    shaded = NULL, deceased = NULL,
-                    starred = NULL, hints = NULL, fouInb = "autosomal",
-                    margins = c(0.6, 1, 4.1, 1),
-                    keep.par = FALSE, skipEmptyGenotypes = NULL,
-                    skip.empty.genotypes = NULL, id.labels = NULL, ...) {
-
-  if(!is.null(id.labels)) {
-    message("The `id.labels` argument is deprecated in favor of `labs`, and will be removed in a future version")
-    if(length(id.labels) == pedsize(x) && is.null(names(id.labels))) # special case
-      labs = setNames(labels(x), id.labels)
-    else labs = id.labels
-  }
-
-  if(!is.null(skip.empty.genotypes)) {
-    message("The `skip.empty.genotypes` argument has been replaced by `showEmpty` and will be removed in a future version")
-    showEmpty = !skip.empty.genotypes
-  }
-  if(!is.null(skipEmptyGenotypes)) {
-    message("The `skipEmptyGenotypes` argument has been replaced by `showEmpty` and will be removed in a future version")
-    showEmpty = !skipEmptyGenotypes
-  }
+                    labs = labels(x), title = NULL, col = 1, aff = NULL, carrier = NULL,
+                    hatched = NULL, shaded = NULL, deceased = NULL,
+                    starred = NULL, textInside = NULL, textAbove = NULL,
+                    hints = NULL, fouInb = "autosomal",
+                    margins = c(0.6, 1, 4.1, 1), keep.par = FALSE, ...) {
 
   if(hasSelfing(x))
     stop2("Plotting of pedigrees with selfing is not yet supported")
@@ -202,18 +190,21 @@ plot.ped = function(x, marker = NULL, sep = "/", missing = "-", showEmpty = FALS
     text = if (!any(nzchar(text))) geno else paste(text, geno, sep = "\n")
   }
 
-  # Needed for centered title. Without, par() doesnt equal 'margins'...(why??)
+  # Needed for centred title. Without, par() doesn't equal 'margins'...(why??)
   opar = par(mar = margins)
   if(!keep.par)
     on.exit(par(opar))
 
   # Colours
   if(is.list(col)) {
-    colnames = names(col)
     cols = rep(1, nInd)
-    for(cc in colnames) {
-      ids_col = intersect(labels(x), col[[cc]])
-      cols[internalID(x, ids_col)] = cc
+    for(cc in names(col)) {
+      thiscol = col[[cc]]
+      if(is.function(thiscol))
+        idscol = thiscol(x)
+      else
+        idscol = intersect(labels(x), thiscol)
+      cols[internalID(x, idscol)] = cc
     }
   }
   else {
@@ -250,19 +241,43 @@ plot.ped = function(x, marker = NULL, sep = "/", missing = "-", showEmpty = FALS
   pdat = kinship2::plot.pedigree(pedigree, id = text, col = cols, mar = margins,
                                  density = density, angle = angle, keep.par = keep.par, ...)
 
-  # Add title
-  if (!is.null(title)) title(title)
+  # Expand dots (needed in some commands below)
+  dotArgs.uneval = match.call(expand.dots = FALSE)$`...`
+  dotArgs = lapply(dotArgs.uneval, eval.parent, n = 2L)
+  cex = dotArgs[['cex']]
+  fam = dotArgs[['family']]
 
-  # Add founder inbreeding coefficients
-  if(!is.null(fouInb) && hasInbredFounders(x)) {
+  # Add title
+  if (!is.null(title))
+    title(title, cex.main = dotArgs$cex.main %||% cex, col.main = dotArgs$col.main,
+          font.main = dotArgs$font.main, fam = fam, xpd = NA)
+
+  # Add carrier dots
+  if(is.function(carrier))
+    carrier = carrier(x)
+  carrier = internalID(x, carrier, errorIfUnknown = FALSE)
+  points(pdat$x[carrier], pdat$y[carrier] + pdat$boxh/2, pch = 16, cex = cex, col = cols[carrier])
+
+  # Text inside symbols
+  if(!is.null(textInside)) {
+    text(pdat$x, pdat$y + pdat$boxh/2, labels = textInside, cex = cex, col = cols,
+         font = dotArgs[['font']], fam = fam)
+  }
+
+  # Text above pedigree symbols
+  if(!is.null(textAbove)) {
+    text(pdat$x, pdat$y, labels = textAbove, cex = cex, col = cols,
+         font = dotArgs[['font']], fam = fam, adj = c(0.5, -0.5), xpd = TRUE)
+  }
+  else if(!is.null(fouInb) && hasInbredFounders(x)) {
+    # Add founder inbreeding coefficients
     finb = founderInbreeding(x, chromType = fouInb, named = TRUE)
     finb = finb[finb > 0]
     idx = internalID(x, names(finb))
     finb.txt = sprintf("f = %.4g", finb)
-    cex = match.call(expand.dots = FALSE)$`...`$cex # NULL is ok!
 
-    text(pdat$x[idx], pdat$y[idx], labels = finb.txt,
-         cex = cex, font = 3, adj = c(0.5, -0.5), xpd = TRUE)
+    text(pdat$x[idx], pdat$y[idx], labels = finb.txt, cex = cex, font = 3,
+         fam = fam, adj = c(0.5, -0.5), xpd = TRUE)
   }
 
   invisible(pdat)
@@ -272,22 +287,10 @@ plot.ped = function(x, marker = NULL, sep = "/", missing = "-", showEmpty = FALS
 #' @export
 plot.singleton = function(x, marker = NULL, sep = "/", missing = "-", showEmpty = FALSE,
                           labs = labels(x), title = NULL, col = 1, aff = NULL,
-                          hatched = NULL, shaded = NULL,
-                          deceased = NULL, starred = NULL, fouInb = "autosomal",
-                          margins = c(8, 0, 0, 0), yadj = 0, id.labels = NULL, ...) {
-
-  if(!is.null(id.labels)) {
-    message("The `id.labels` argument is deprecated in favor of `labs`, and will be removed in a future version")
-    if(length(id.labels) == pedsize(x) && is.null(names(id.labels))) # special case
-      labs = setNames(labels(x), id.labels)
-    else labs = id.labels
-  }
-
-  # Founder inbreeding (this must be extracted before addParents())
-  if(!is.null(fouInb) && hasInbredFounders(x))
-    finb = founderInbreeding(x, chromType = fouInb) #names unneccesary
-  else
-    finb = NULL
+                          carrier = NULL, hatched = NULL, shaded = NULL,
+                          deceased = NULL, starred = NULL,
+                          textInside = NULL, textAbove = NULL, fouInb = "autosomal",
+                          margins = c(8, 0, 0, 0), yadj = 0, ...) {
 
   # Tweak labels if necessary. After addParents, internal index is 3!
   if(is.function(labs))
@@ -299,6 +302,9 @@ plot.singleton = function(x, marker = NULL, sep = "/", missing = "-", showEmpty
   if(is.function(aff))
     aff = aff(x)
 
+  if(is.function(carrier))
+    carrier = carrier(x)
+
   if(!is.null(shaded)) {
     hatched = shaded
     shaded = NULL
@@ -310,6 +316,18 @@ plot.singleton = function(x, marker = NULL, sep = "/", missing = "-", showEmpty
   if(is.function(starred))
     starred = starred(x)
 
+  if(!is.null(textInside))
+    textInside = c("", "", textInside)
+
+  if(!is.null(textAbove))
+    textAbove = c("", "", textAbove)
+
+  # Founder inbreeding (this must be extracted before addParents())
+  if(!is.null(fouInb) && hasInbredFounders(x))
+    finb = founderInbreeding(x, chromType = fouInb) #names unneccesary
+  else
+    finb = NULL
+
   # Markers: Must be attached to `x` before addParents
   if (length(marker) == 0)
     mlist = NULL
@@ -333,22 +351,35 @@ plot.singleton = function(x, marker = NULL, sep = "/", missing = "-", showEmpty
 
   pdat = plot.ped(y, marker = y$MARKERS, sep = sep, missing = missing,
                showEmpty = showEmpty, labs = labs,
-               title = title, col = col, aff = aff, hatched = hatched, shaded = shaded, deceased = deceased,
-               starred = starred, margins = c(margins[1], 0, 0, 0), keep.par = TRUE, ...)
+               title = title, col = col, aff = aff, carrier = carrier,
+               hatched = hatched, shaded = shaded, deceased = deceased,
+               starred = starred, textInside = textInside, textAbove = textAbove,
+               margins = c(margins[1], 0, 0, 0), keep.par = TRUE, ...)
 
   usr = par("usr")
   rect(usr[1] - 0.1, pdat$y[3] - yadj, usr[2] + 0.1, usr[4], border = NA, col = "white")
 
-  # Add title
-  if (!is.null(title)) title(title, line = -2.8)
 
-  # Add founder inbreeding coefficients
-  if(!is.null(finb)) {
+  # Expand dots (needed in some commands below)
+  dotArgs = match.call(expand.dots = FALSE)$`...`
+  cex = dotArgs[['cex']]
+  fam = dotArgs$family
+
+  # Add title
+  if (!is.null(title))
+    title(title, cex.main = dotArgs$cex.main %||% cex, col.main = dotArgs$col.main, line = -2.8,
+          font.main = dotArgs$font.main, family = fam, xpd = NA)
+
+  # Text above pedigree symbols
+  if(!is.null(textAbove)) {
+    text(pdat$x, pdat$y, labels = textAbove, cex = cex, col = col,
+         font = dotArgs[['font']], family = fam, adj = c(0.5, -0.5), xpd = TRUE)
+  }
+  else if(!is.null(finb)) {
     finb.txt = sprintf("f = %.4g", finb)
-    cex = match.call(expand.dots = FALSE)$`...`$cex # NULL is ok!
     idx = 3 # the "child"
 
-    text(pdat$x[idx], pdat$y[idx], labels = finb.txt,
+    text(pdat$x[idx], pdat$y[idx], labels = finb.txt, family = fam,
          cex = cex, font = 3, adj = c(0.5, -0.5), xpd = TRUE)
   }
 
