@@ -152,7 +152,7 @@ validate_sex = function(sex, nInd, zero_allowed = TRUE) {
   sex_int = suppressWarnings(as.integer(sex))
   ok = (sex == sex_int) & sex_int %in% codes
   if(!all(ok))
-    stop2("Illegal gender code: ", unique(sex[!ok]),
+    stop2("Illegal sex: ", unique(sex[!ok]),
           ".  [0 = NA; 1 = male; 2 = female]")
   invisible(rep_len(sex_int, nInd))
 }
@@ -258,7 +258,7 @@ print.nucleus = function(x, ...) {
 }
 
 
-has_numlabs = function(x) {
+hasNumLabs = function(x) {
   # Returns TRUE if the labels of x are coercible to integers
   labs = labels(x)
   numlabs = suppressWarnings(as.character(as.integer(labs)))
